@@ -128,6 +128,10 @@ GCJ_New (NPMIMEType pluginType, NPP instance, uint16 mode,
   if (!instance)
     return NPERR_INVALID_INSTANCE_ERROR;
 
+  // Initialize threads (needed for mutexes).
+  if (!g_thread_supported ())
+    g_thread_init (NULL);
+  
   NPError tmp = NPERR_NO_ERROR;
   
   g_mutex_lock (mutex_appletviewer_process);
@@ -326,7 +330,13 @@ GCJ_SetWindow (NPP instance, NPWindow* window)
   else
     {
       PLUGIN_DEBUG ("GCJ_SetWindow: setting window\n");
-      data->xid = g_strdup_printf ("xid %d", (int)(window->window));
+#if SIZEOF_VOID_P == 4 // We are on a 32-bit architecture.
+      data->xid = g_strdup_printf ("xid %d", (int) (window->window));
+#elif SIZEOF_VOID_P == 8 // We are on a 64-bit architecture.
+      data->xid = g_strdup_printf ("xid %ld", (long) (window->window));
+#else // We are on an architecture with unkown pointer size.
+#error "Unknown pointer size."
+#endif
 
       send_message_to_appletviewer (data->instance_id);
       send_message_to_appletviewer (data->xid);
@@ -529,11 +539,11 @@ start_appletviewer_process(void)
   
   if (searchpath != NULL)
     {
-      newpath = strcat(searchpath, ":/home/mkoch/local/gcjwebplugin/bin");
+      newpath = strcat(searchpath, ":" PREFIX "/bin");
     }
   else
     {
-      newpath = "/home/mkoch/local/gcjwebplugin/bin";
+      newpath = ":" PREFIX "/bin";
     }
 
   setenv("PATH", newpath, 1);
@@ -682,6 +692,8 @@ NP_Shutdown(void)
 	  g_printerr ("NP_Shutdown: Error: %s\n", err->message);
 	  return NPERR_GENERIC_ERROR;
 	}
+
+      output_to_appletviewer = NULL;
     }
 
   if (input_from_appletviewer)
@@ -692,8 +704,14 @@ NP_Shutdown(void)
 	  g_printerr ("NP_Shutdown: Error: %s\n", err->message);
 	  return NPERR_GENERIC_ERROR;
 	}
+      
+      input_from_appletviewer = NULL;
     }
 
+  // Free mutex.
+  g_mutex_free (mutex_appletviewer_process);
+  mutex_appletviewer_process = NULL;
+  
   // Delete named pipes.
   gchar *pipename_in = g_strdup_printf ("/tmp/gcjwebplugin-%i-in", getpid ());
   gchar *pipename_out = g_strdup_printf ("/tmp/gcjwebplugin-%i-out", getpid ());
