@@ -1,5 +1,5 @@
 /* AppletTag.java - representation of an HTML APPLET tag
-   Copyright (C) 2003, 2004  Thomas Fitzsimmons <fitzsim@redhat.com>
+   Copyright (C) 2003, 2004, 2005  Thomas Fitzsimmons <fitzsim@redhat.com>
 
    This file is part of GCJ Applet Viewer.
 
@@ -108,6 +108,9 @@ class AppletTag
 
     while (tagTokenizer.nextToken() != '>')
       {
+	if (tagTokenizer.ttype == StreamTokenizer.TT_EOF)
+	  break;
+
 	if (tagTokenizer.ttype == StreamTokenizer.TT_WORD)
 	  {
 	    if (tagTokenizer.sval.equals("name"))
@@ -422,6 +425,16 @@ class AppletTag
 	  }
 	token = tagTokenizer.nextToken();
       }
+
+    // If we hit EOF, just go ahead with whatever we've got.  Some
+    // pages don't properly terminate; besides which our parser is a
+    // bit bogus anyway.
+    if (currentTag != null)
+      {
+	currentTag.parseArchives();
+	return currentTag;
+      }
+
     return null;
   }
 
@@ -436,42 +449,46 @@ class AppletTag
   public static Dimension getSize (AppletTag tag)
   {
     NumberFormat numberFormat;
-    Dimension size = new Dimension();
+    Dimension size = new Dimension(320, 200);
 
     try
       {
 	String widthStr = (String) tag.parameters.get("width");
 
-	if (widthStr.charAt(widthStr.length() - 1) == '%')
-	  numberFormat = NumberFormat.getPercentInstance(Locale.US);
-	else
-	  numberFormat = NumberFormat.getInstance(Locale.US);
+	if (widthStr != null)
+	  {
+	    if (widthStr.charAt(widthStr.length() - 1) == '%')
+	      numberFormat = NumberFormat.getPercentInstance(Locale.US);
+	    else
+	      numberFormat = NumberFormat.getInstance(Locale.US);
 
-	// FIXME: Handle percentage somehow.
-	size.width = numberFormat.parse(widthStr).intValue();
+	    // FIXME: Handle percentage somehow.
+	    size.width = numberFormat.parse(widthStr).intValue();
+	  }
       }
     catch (ParseException e)
       {
 	// Use default.
-	size.width = 320;
       }
 
     try
       {
 	String heightStr = (String) tag.parameters.get("height");
 
-	if (heightStr.charAt(heightStr.length() - 1) == '%')
-	  numberFormat = NumberFormat.getPercentInstance(Locale.US);
-	else
-	  numberFormat = NumberFormat.getInstance(Locale.US);
+	if (heightStr != null)
+	  {
+	    if (heightStr.charAt(heightStr.length() - 1) == '%')
+	      numberFormat = NumberFormat.getPercentInstance(Locale.US);
+	    else
+	      numberFormat = NumberFormat.getInstance(Locale.US);
 
-	// FIXME: Handle percentage somehow.
-	size.height = numberFormat.parse(heightStr).intValue();
+	    // FIXME: Handle percentage somehow.
+	    size.height = numberFormat.parse(heightStr).intValue();
+	  }
       }
     catch (ParseException e)
       {
 	// Use default.
-	size.height = 200;
       }
 
     return size;
