@@ -92,6 +92,9 @@ class AppletViewer
       {
 	e.printStackTrace();
       }
+
+    if (applet == null)
+      applet = new ErrorApplet("Error loading applet");
     
     return applet;
   }
@@ -139,22 +142,7 @@ class AppletViewer
 
     List argsList = new LinkedList(Arrays.asList(args));
 
-    // Check for the -debug option, for appletviewer compatibility.
-    // The -debug option can be given multiple times on the command
-    // line.
-
-    // FIXME: The debug option will be unsupported until we have the
-    // ability to debug bytecode.  For now, just strip it out of the
-    // argument list.
     Iterator argsIter = argsList.iterator();
-    while (argsIter.hasNext())
-      {
-	String currentArg = (String) argsIter.next();
-	if (currentArg.equals("--"))
-	  break;
-	else if (currentArg.equals("-debug"))
-	  argsIter.remove();
-      }
 
     // Check for the -encoding option, for appletviewer compatibility.
     // The -encoding option can be given multiple times on the command
@@ -185,32 +173,6 @@ class AppletViewer
 	  }
       }
 
-    // Check for -J options, for appletviewer compatibility.
-
-    // FIXME: currently we ignore these options.  What are their gcj
-    // equivalents and how do we pass them to the runtime?
-    argsIter = argsList.iterator();
-    while (argsIter.hasNext())
-      {
-	String currentArg = (String) argsIter.next();
-
-	if (currentArg.length() == 2)
-	  {
-	    if (currentArg.equals("--"))
-	      break;
-	    else if (currentArg.equals("-J"))
-	      {
-		System.err.println("gcjappletviewer: the -J option should not be followed by a space.");
-		printHelpMessage(1);
-	      }
-	  }
-	else if (currentArg.length() > 2)
-	  {
-	    if (currentArg.substring(0, 2).equals("-J"))
-	      argsIter.remove();
-	  }
-      }
-
     args = (String[]) argsList.toArray(new String[argsList.size()]);
 
     LongOpt[] longOptions =
