@@ -153,11 +153,13 @@ class PluginAppletViewer
 
     stdOut.println("  PIPE: applet viewer read: " + message);
 
-    if (message.equals("shutdown"))
+    if (message == null || message.equals("shutdown"))
       {
 	// Close input/output channels to plugin.
 	pluginInputStream.close();
 	pluginOutputStream.close();
+
+	System.out.println("Exiting plugin applet viewer!");
 	System.exit(0);
       }
 
