@@ -38,7 +38,6 @@ import java.util.HashMap;
 
 class PluginAppletWindow extends EmbeddedWindow
 {
-  private static int testWindowCount;
   private static HashMap contexts = new HashMap();
   private Applet applet;
   private AppletTag tag;
@@ -85,33 +84,20 @@ class PluginAppletWindow extends EmbeddedWindow
 
     AppletContext context = (AppletContext) contexts.get(tag.codebase);
     ((PluginAppletContext) context).addApplet(applet);
+
     applet.setStub(new CommonAppletStub(tag, context, applet));
 
-    String testWindowCount = System.getProperty("gnu.gcjwebplugin.test.windowCount");
+    Dimension size = AppletTag.getSize (tag);
+    setSize (size.width, size.height);
+    applet.setSize (size);
 
-    if (testWindowCount == null)
-      {
-        // Synchronize on the system event queue when showing and
-        // initializing the applet so that it doesn't receive events
-        // before it has been initialized.
-        synchronized (Toolkit.getDefaultToolkit ().getSystemEventQueue ())
-          {
-            setVisible (true);
-            applet.init ();
-          }
-
-	applet.validate();
-	applet.start();
-      }
-    else
-      {
-	applet.init();
-	applet.start();
-
-	if (++this.testWindowCount == Integer.decode(testWindowCount)
-	                                       .intValue())
-	  System.exit(0);
-      }
+    // Initialize the applet before showing this window so that
+    // the applet doesn't receive events before it has been
+    // initialized.
+    applet.init ();
+    setVisible (true);
+    applet.validate();
+    applet.start();
   }
 
   /////////////////////////////
