@@ -1,5 +1,5 @@
 /* StandaloneAppletWindow.java -- an applet frame
-   Copyright (C) 2003  Thomas Fitzsimmons <fitzsim@redhat.com>
+   Copyright (C) 2003, 2004  Thomas Fitzsimmons <fitzsim@redhat.com>
 
    This file is part of GCJ Applet Viewer.
 
@@ -37,10 +37,8 @@ import java.awt.event.ActionEvent;
 import java.awt.event.ActionListener;
 import java.awt.event.WindowAdapter;
 import java.awt.event.WindowEvent;
-import java.text.NumberFormat;
-import java.text.ParseException;
 import java.util.HashMap;
-import java.util.List; import java.util.Locale;
+import java.util.List;
 
 class StandaloneAppletWindow extends Frame
   implements ActionListener
@@ -56,6 +54,12 @@ class StandaloneAppletWindow extends Frame
   private MenuItem saveItem;
   private MenuItem startItem;
   private MenuItem cloneItem;
+  private MenuItem tagItem;
+  private MenuItem infoItem;
+  private MenuItem editItem;
+  private MenuItem encodingItem;
+  private MenuItem printItem;
+  private MenuItem propertiesItem;
   private MenuItem closeItem;
   private MenuItem quitItem;
 
@@ -82,19 +86,51 @@ class StandaloneAppletWindow extends Frame
         });
 
     restartItem = new MenuItem(AppletViewer.messages.getString("gcjwebplugin.menu_restart"));
+    restartItem.setEnabled(false);
     restartItem.addActionListener(this);
     reloadItem = new MenuItem(AppletViewer.messages.getString("gcjwebplugin.menu_reload"));
+    reloadItem.setEnabled(false);
     reloadItem.addActionListener(this);
     cancelItem = new MenuItem(AppletViewer.messages.getString("gcjwebplugin.menu_cancel"));
+    cancelItem.setEnabled(false);
     cancelItem.addActionListener(this);
     saveItem = new MenuItem(AppletViewer.messages.getString("gcjwebplugin.menu_save"));
+    saveItem.setEnabled(false);
     saveItem.addActionListener(this);
     startItem = new MenuItem(AppletViewer.messages.getString("gcjwebplugin.menu_start"));
+    startItem.setEnabled(false);
     startItem.addActionListener(this);
     cloneItem = new MenuItem(AppletViewer.messages.getString("gcjwebplugin.menu_clone"));
+    cloneItem.setEnabled(false);
     cloneItem.addActionListener(this);
     closeItem = new MenuItem(AppletViewer.messages.getString("gcjwebplugin.menu_close"));
+    closeItem.setEnabled(false);
     closeItem.addActionListener(this);
+    tagItem =
+      new MenuItem(AppletViewer.messages.getString("gcjwebplugin.menu_tag"));
+    tagItem.setEnabled(false);
+    tagItem.addActionListener(this);
+    infoItem =
+      new MenuItem(AppletViewer.messages.getString("gcjwebplugin.menu_info"));
+    infoItem.setEnabled(false);
+    infoItem.addActionListener(this);
+    editItem =
+      new MenuItem(AppletViewer.messages.getString("gcjwebplugin.menu_edit"));
+    editItem.setEnabled(false);
+    editItem.addActionListener(this);
+    editItem.setEnabled(false);
+    encodingItem =
+      new MenuItem(AppletViewer.messages.getString("gcjwebplugin.menu_encoding"));
+    encodingItem.setEnabled(false);
+    encodingItem.addActionListener(this);
+    printItem =
+      new MenuItem(AppletViewer.messages.getString("gcjwebplugin.menu_print"));
+    printItem.setEnabled(false);
+    printItem.addActionListener(this);
+    propertiesItem =
+      new MenuItem(AppletViewer.messages.getString("gcjwebplugin.menu_properties"));
+    propertiesItem.setEnabled(false);
+    propertiesItem.addActionListener(this);
     quitItem = new MenuItem(AppletViewer.messages.getString("gcjwebplugin.menu_quit"));
     quitItem.addActionListener(this);
 
@@ -108,41 +144,46 @@ class StandaloneAppletWindow extends Frame
     menuApplet.add(startItem);
     menuApplet.add(cloneItem);
     menuApplet.addSeparator();
+    menuApplet.add(tagItem);
+    menuApplet.add(infoItem);
+    menuApplet.add(editItem);
+    menuApplet.add(encodingItem);
+    menuApplet.addSeparator();
+    menuApplet.add(printItem);
+    menuApplet.addSeparator();
+    menuApplet.add(propertiesItem);
+    menuApplet.addSeparator();
     menuApplet.add(closeItem);
     menuApplet.add(quitItem);
     setMenuBar(menuBar);
 
+    setTitle("GCJ Applet Viewer: " + tag.code);
+
     AppletContext context = (AppletContext) contexts.get(tag.codebase);
     ((StandaloneAppletContext) context).addApplet(applet);
 
     applet.setStub(new CommonAppletStub(tag, context, applet));
 
-    setTitle("GCJ Applet Viewer: " + tag.code);
-
-    String testWindowCount =
+    String testWindowCountProperty =
       System.getProperty("gnu.gcjwebplugin.test.windowCount");
 
-    if (testWindowCount == null)
+    if (testWindowCountProperty == null)
       {
 	// Create the frame's peer.  Otherwise getPreferredSize will read
 	// its insets as 0.
 	addNotify();
         Insets i = getInsets ();
-	Dimension size = getSizeFromTag(tag);
+	Dimension size = AppletTag.getSize (tag);
 	setSize(i.left + size.width + i.right,
 		i.top + size.height + status.getPreferredSize ().height
 		+ i.bottom);
         applet.setSize(size);
 
-        // Synchronize on the system event queue when showing and
-        // initializing the applet so that it doesn't receive events
-        // before it has been initialized.
-        synchronized (Toolkit.getDefaultToolkit ().getSystemEventQueue ())
-          {
-            setVisible (true);
-            applet.init ();
-          }
-
+        // Initialize the applet before showing this window so that
+        // the applet doesn't receive events before it has been
+        // initialized.
+	applet.init ();
+	setVisible (true);
 	applet.validate();
 	applet.start();
       }
@@ -151,63 +192,34 @@ class StandaloneAppletWindow extends Frame
 	applet.init();
 	applet.start();
 
-	if (++StandaloneAppletWindow.testWindowCount == Integer.decode(testWindowCount).intValue())
+	if (++StandaloneAppletWindow.testWindowCount == Integer.decode(testWindowCountProperty).intValue())
 	  System.exit(0);
       }
   }
 
-  private Dimension getSizeFromTag(AppletTag tag)
+  private void closeWindow()
   {
-    NumberFormat numberFormat;
-    Dimension size = new Dimension();
-
-    try
-      {
-	String widthStr = (String) tag.parameters.get("width");
-
-	if (widthStr.charAt(widthStr.length() - 1) == '%')
-	  numberFormat = NumberFormat.getPercentInstance(Locale.US);
-	else
-	  numberFormat = NumberFormat.getInstance(Locale.US);
-
-	// FIXME: Handle percentage somehow.
-	size.width = numberFormat.parse(widthStr).intValue();
-      }
-    catch (ParseException e)
-      {
-	// Use default.
-	size.width = 320;
-      }
-
-    try
-      {
-	String heightStr = (String) tag.parameters.get("height");
-
-	if (heightStr.charAt(heightStr.length() - 1) == '%')
-	  numberFormat = NumberFormat.getPercentInstance(Locale.US);
-	else
-	  numberFormat = NumberFormat.getInstance(Locale.US);
-
-	// FIXME: Handle percentage somehow.
-	size.height = numberFormat.parse(heightStr).intValue();
-      }
-    catch (ParseException e)
-      {
-	// Use default.
-	size.height = 200;
-      }
-
-    return size;
+    applet.stop();
+    StandaloneAppletViewer.appletWindows.remove(this);
+    StandaloneAppletWindow.this.hide();
   }
 
   public void actionPerformed(ActionEvent e)
   {
     if (e.getSource() == quitItem)
       {
-        applet.stop();
-        StandaloneAppletWindow.this.hide();
+        closeWindow();
         System.exit(0);
       }
+    else if (e.getSource() == closeItem)
+      {
+	// Close current window.
+	closeWindow();
+	
+	// Exit if there are other windows left.
+	if (StandaloneAppletViewer.appletWindows.isEmpty())
+          System.exit(0);
+      }
   }
 
   void showStatus(String status)
