@@ -1,3 +1,4 @@
+import java.awt.*;
 import java.applet.*;
 import java.io.*;
 import java.util.*;
@@ -32,5 +33,8 @@ public class TestAppletCodebaseOne2 extends Applet
   public void start ()
   {
     System.out.println ("TestAppletCodebaseOne2.start");
+    System.out.println ("codebase one 2 applet current keyboard manager: " + KeyboardFocusManager.getCurrentKeyboardFocusManager ());
+    System.out.println ("codebase one 2 applet context: " + getAppletContext ());
+    System.out.println ("codebase one 2 thread group: " + Thread.currentThread ().getThreadGroup ());
   }
 }
